#include "Debug/plDebug.h"
#include "PRP/Audio/plSoundBuffer.h"
#include <vector>
#include <algorithm>

int main(int argc, char** argv) {
    if (argc < 2) {
        printf("Usage: %s AgeName.age [AgeName.age ...]\n\n", argv[0]);
        return 1;
    }

    plDebug::Init(plDebug::kDLError);
    plResManager rm;
    for (int ai=1; ai<argc; ai++) {
        std::vector<plString> sounds;
        try {
            plAgeInfo* age = rm.ReadAge(argv[ai], true);
            printf("* %s\n", age->getAgeName().cstr());
            for (size_t i=0; i<age->getNumPages(); i++) {
                std::vector<plKey> keys = rm.getKeys(age->getPageLoc(i), kSoundBuffer);
                size_t base = sounds.size();
                sounds.resize(base + keys.size());
                for (size_t j=0; j<keys.size(); j++) {
                    plSoundBuffer* sound = plSoundBuffer::Convert(keys[j]->getObj());
                    sounds[base + j] = sound->getFileName();
                }
            }
            std::sort(sounds.begin(), sounds.end());
            std::unique(sounds.begin(), sounds.end());
            for (size_t i=0; i<sounds.size(); i++)
                printf("  - %s\n", sounds[i].cstr());
        } catch (hsException& e) {
            printf("Error reading %s: %s\n", argv[ai], e.what());
        } catch (...) {
            printf("Error reading %s\n", argv[ai]);
        }
    }
    return 0;
}
